@@ -14,6 +14,7 @@ AUTH_VALUE = 'auth_value'
 from expiringdict import ExpiringDict
 cache = ExpiringDict(max_len=100, max_age_seconds=10)
 
+
 class JWTAuth(TokenAuth):
     """
     Implements JWT token validation support.
@@ -26,10 +27,10 @@ class JWTAuth(TokenAuth):
     @property
     def validator(self):
         if self._validator is None:
-            ttl = config.get("JWT_TTL", 3600)
+            ttl = config.JWT_TTL or 3600
 
-            scope_claim = config.get("JWT_SCOPE_CLAIM", None)
-            roles_claim = config.get("JWT_ROLES_CLAIM", None)
+            scope_claim = config.JWT_SCOPE_CLAIM
+            roles_claim = config.JWT_ROLES_CLAIM
             self._validator = AsymmetricKeyValidator(key_url=config.JWT_KEY_URL, ttl=ttl,
                                         scope_claim=scope_claim, roles_claim=roles_claim)
         return self._validator
@@ -41,7 +42,7 @@ class JWTAuth(TokenAuth):
     @property
     def issuer(self):
         if self._issuer is None:
-            return config.get("JWT_ISSUER", "")
+            return config.JWT_ISSUER
         return self._issuer
 
     @issuer.setter
@@ -108,7 +109,7 @@ class JWTAuth(TokenAuth):
         If the validation succeed, the claims are stored and accessible thru the
         get_authen_claims() method.
         """
-        domain = config.get("DOMAIN", {})
+        domain = config.DOMAIN or {}
         resource_conf = domain.get(resource, {})
         audiences = resource_conf.get('audiences', config.JWT_AUDIENCES)
         return self._perform_validation(token, audiences, allowed_roles)
